[![forthebadge](https://forthebadge.com/images/badges/built-with-love.svg)](https://www.gobolinux.org/)
[![forthebadge](https://forthebadge.com/images/badges/made-with-ruby.svg)](https://www.ruby-lang.org/en/)
[![Gem Version](https://badge.fury.io/rb/beautiful_url.svg)](https://badge.fury.io/rb/beautiful_url)

This gem was <b>last updated</b> on the <span style="color: darkblue; font-weight: bold">05.04.2023</span> (dd.mm.yyyy notation), at <span style="color: steelblue; font-weight: bold">20:13:11</span> o'clock.

## Introducing the BeautifulUrl project

<img src="https://i.imgur.com/w9Ws8CP.png" style="margin:1em; border: 3px solid black;">

This project has been created to primarily cover my needs to map a
given input (typically a symbol, such as :ruby_homepage), to
a specific String - a remote URL, in this case
**https://www.ruby-lang.org/en/**.

In fact this is the primary scenario for this project: it provides
a simple mapper between symbols, and remote URLs.

At a later time I also added symbols as shortcuts to local files,
so the whole project is a quick way for me to navigate different
resources (including **RESTful APIs**).

I may at a later point add the ability to arbitrarily add new
entries via a yaml file, so that other people can extend this
project at their own leisure - but for now, the original use
case will be kept as-is. Extending the project may happen at
a later time.

## General usage examples

    BeautifulUrl::BeautifulUrl.new('palemoon', :replace_localhost)
    BeautifulUrl::BeautifulUrl.new('palemoon' {{ replace_localhost: true }}
    BeautifulUrl['palemoon'] # ← This is recommended, as it is simpler.

## Creating a .json file

It is possible to create a local .json file containing all the
remote URLs that are registered. The method to do so is
called <b>BeautifulUrl.create_json_file()</b>. Note that
this functionality depends on the <b>case_parser</b> gem;
that gem does not work 100% accurately, so do not be surprised
if you do not get a complete .json file but only one with
the first entry matched. In the future this may be changed,
but for now this is the way it is.

## Sinatra-Interface

The BeautifulUrl project has a minimalistic **sinatra interface**.

You can start it in this way:

    require 'beautiful_url/www/app.rb'

    BeautifulUrl::App.start_sinatra_interface

Note that this depends on an external gem (the **cyberweb** project).
The reason why that dependency exists is because it makes it easier
for me to handle the same or similar code across many different
ruby-based projects.

The main purpose of this Application is to map given string input into
the corresponding URL. It's mostly added for demonstration-purposes,
to show how this could be used in a web-interface.

One day I may also want to add a small widget to a browser to 
allow for this, but I don't like javascript, and don't know
how to do this via ruby only either.


## Contact information and mandatory 2FA coming up in 2022

If your creative mind has ideas and specific suggestions to make this gem
more useful in general, feel free to drop me an email at any time, via:

    shevy@inbox.lt

Before that email I used an email account at Google gmail, but in **2021** I
decided to slowly abandon gmail, for various reasons. In order to limit the
explanation here, allow me to just briefly state that I do not feel as if I
want to promote any Google service anymore when the user becomes the 
product (such as via data collection by upstream services). I feel this is
a hugely flawed business model.

Do keep in mind that responding to emails may take some time, depending on
the amount of work I may have at that moment.

In <b>2022</b> rubygems.org, or rather the corporate overlords who control the
rubygems.org infrastructure these days, decided to make 2FA mandatory for every
gem owner eventually: see
https://blog.rubygems.org/2022/06/13/making-packages-more-secure.html

Mandatory 2FA will eventually be extended to all rubygems.org developers and
maintainers. As I can not use 2FA, for reasons I will skip explaining here,
this means that my projects will eventually be taken over by shopify (or,
correspondingly, whoever effectively controls the rubygems.org ecosystem).
At that point, I no longer have any control what is done to my projects
since shopify (respectively those controlling the gems ecosystem) took away
control here. Not sure at which point ruby became corporate-controlled -
that was not the case several years ago.

Ruby also only allows 2FA users to participate on the issue tracker these
days:

  https://bugs.ruby-lang.org/issues/18800

